@@ -1,24 +1,24 @@
 package Date::Japanese::Era::Table;
 
+use utf8;
 use strict;
-use vars qw($VERSION);
-$VERSION = '0.04';
+our $VERSION = '0.04';
 
-use vars qw(@ISA @EXPORT %ERA_TABLE %ERA_JA2ASCII %ERA_ASCII2JA);
 require Exporter;
-@ISA    = qw(Exporter);
-@EXPORT = qw(%ERA_TABLE %ERA_JA2ASCII %ERA_ASCII2JA);
+our @ISA    = qw(Exporter);
+our @EXPORT = qw(%ERA_TABLE %ERA_JA2ASCII %ERA_ASCII2JA);
 
-%ERA_TABLE = (
+our %ERA_TABLE = (
     # era => [ $ascii, @begin_ymd, @end_ymd ]
-    "\x{660E}\x{6CBB}" => [ 'meiji', 1868, 9, 8, 1912, 7, 29 ],
-    "\x{5927}\x{6B63}" => [ 'taishou', 1912, 7, 30, 1926, 12, 24 ],
-    "\x{662D}\x{548C}" => [ 'shouwa', 1926, 12, 25, 1989, 1, 7 ],
-    "\x{5E73}\x{6210}" => [ 'heisei', 1989, 1, 8, 2999, 12, 31 ], # XXX
+    "明治" => [ 'meiji', 1868, 9, 8, 1912, 7, 29 ],
+    "大正" => [ 'taishou', 1912, 7, 30, 1926, 12, 24 ],
+    "昭和" => [ 'shouwa', 1926, 12, 25, 1989, 1, 7 ],
+    "平成" => [ 'heisei', 1989, 1, 8, 2019, 4, 30 ],
+    "令和" => [ 'reiwa', 2019, 5, 1, 2999, 12, 31 ], # XXX
 );
 
-%ERA_JA2ASCII = map { $_ => $ERA_TABLE{$_}->[0] } keys %ERA_TABLE;
-%ERA_ASCII2JA = reverse %ERA_JA2ASCII;
+our %ERA_JA2ASCII = map { $_ => $ERA_TABLE{$_}->[0] } keys %ERA_TABLE;
+our %ERA_ASCII2JA = reverse %ERA_JA2ASCII;
 
 1;
 __END__
